ArcedConnector

Struct ArcedConnector 

pub struct ArcedConnector(/* private fields */);
An Arced and type-erased Connector

Implementations

Source

impl ArcedConnector

pub fn new(connector: impl Connector) -> Self

Constructs a new ArcedConnector

pub fn is<T: Any + 'static>(&self) -> bool

Determine if this ArcedConnector is the specified type

pub fn downcast_ref<T: Any + 'static>(&self) -> Option<&T>

Attempt to borrow this ArcedConnector as the provided type, returning None if it does not contain the type

pub fn downcast_mut<T: Any + 'static>(&mut self) -> Option<&mut T>

Attempt to mutably borrow this ArcedConnector as the provided type, returning None if it does not contain the type or if there are multiple outstanding clones of this arc

pub fn runtime(&self) -> Runtime

Returns an object-safe Runtime