pub struct DroppableFuture<T> { /* private fields */ }Expand description
A wrapper type for futures that do not need to be polled but still can be awaited.
This exists to silence the default #[must_use] that anonymous async functions return
Futures contained by this type must conform to the semantics of trillium join handles described at [RuntimeTrait::spawn].
Implementations
Sourceimpl<T: Future> DroppableFuture<T>
impl<T: Future> DroppableFuture<T>
Sourcepub fn new(future: T) -> Self
pub fn new(future: T) -> Self
Removes the #[must_use] for a future.
This must only be called with a join-handle type future that does not depend on polling to execute.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the inner future.