Runtime

Struct Runtime 

pub struct Runtime(/* private fields */);
A type-erased RuntimeTrait implementation. Think of this as an Arc<dyn RuntimeTrait>

Implementations

Source

impl Runtime

pub fn new(runtime: impl RuntimeTrait) -> Self

Construct a new type-erased runtime object from any RuntimeTrait implementation.

pub fn spawn<Output: Send + 'static>( &self, fut: impl Future<Output = Output> + Send + 'static, ) -> DroppableFuture<Pin<Box<dyn Future<Output = Option<Output>> + Send + 'static>>>

Spawn a future on the runtime, returning a future that has detach-on-drop semantics

Spawned tasks conform to the following behavior:

  • detach on drop: If the returned DroppableFuture is dropped immediately, the task will continue to execute until completion.

  • unwinding: If the spawned future panics, this must not propagate to the join handle. Instead, the awaiting the join handle returns None in case of panic.

pub async fn delay(&self, duration: Duration)

Wake in this amount of wall time

pub fn interval(&self, period: Duration) -> impl Stream<Item = ()> + Send + '_

Returns a Stream that yields a () on the provided period

pub fn block_on<Fut>(&self, fut: Fut) -> Fut::Output
where Fut: Future,

Runtime implementation hook for blocking on a top level future.

pub async fn timeout<Fut>( &self, duration: Duration, fut: Fut, ) -> Option<Fut::Output>
where Fut: Future + Send, Fut::Output: Send + 'static,

Race a future against the provided duration, returning None in case of timeout.