pub struct ArcedConnector(/* private fields */);Expand description
An Arced and type-erased Connector
Implementations
Sourceimpl ArcedConnector
impl ArcedConnector
Sourcepub fn is<T: Any + 'static>(&self) -> bool
pub fn is<T: Any + 'static>(&self) -> bool
Determine if this ArcedConnector is the specified type
Sourcepub fn downcast_ref<T: Any + 'static>(&self) -> Option<&T>
pub fn downcast_ref<T: Any + 'static>(&self) -> Option<&T>
Attempt to borrow this ArcedConnector as the provided type, returning None if it does not
contain the type
Sourcepub fn downcast_mut<T: Any + 'static>(&mut self) -> Option<&mut T>
pub fn downcast_mut<T: Any + 'static>(&mut self) -> Option<&mut T>
Attempt to mutably borrow this ArcedConnector as the provided type, returning None if it
does not contain the type or if there are multiple outstanding clones of this arc