pub trait Acceptor<Input>:
Clone
+ Send
+ Sync
+ 'staticwhere
Input: Transport,{
type Output: Transport;
type Error: Debug + Send + Sync;
// Required method
fn accept(
&self,
input: Input,
) -> impl Future<Output = Result<Self::Output, Self::Error>> + Send;
// Provided method
fn is_secure(&self) -> bool { ... }
}Expand description
This trait provides the common interface for server-side tls acceptors, abstracting over various implementations
The only implementation provided by this crate is (), which is
a noop acceptor, and passes through the Input type.
Required Associated Types
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.